#ifndef NT2_INCLUDE_CONSTANTS_INVLOG_2_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_INVLOG_2_HPP_INCLUDED

#include <nt2/exponential/include/constants/invlog_2.hpp>

#endif
